[Raw Msg Headers][Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

struct token to struct rftc822_token patch.



Here is the patch to the 2.99.49p9 snapshot to fix struct token to struct
rfc822_token so that AIX is happier with the beasty.


diff -u -r zmailer-2.99.49p9/include/libz.h zmailer-2.99.49p9-p0/include/libz.h
--- zmailer-2.99.49p9/include/libz.h	Thu May 22 18:17:14 1997
+++ zmailer-2.99.49p9-p0/include/libz.h	Tue Nov 11 10:21:33 1997
@@ -114,11 +114,11 @@
 extern int  hdr_status __((const char *cp, const char *lbuf, int n, int octo));
 #ifdef Z_TOKEN_H
 extern u_long _hdr_compound __((const char *cp, long n, int cstart, int cend,
-				TokenType type, struct token *tp,
-				struct token **tlist, struct token **tlistp));
-extern const char *_unfold __((const char *start, const char *end, struct token *t));
-extern struct token * scan822 __((const char **cpp, size_t n, int c1, int c2,
-				  int allowcomments, struct token **tlistp));
+				TokenType type, struct rfc822_token *tp,
+				struct rfc822_token **tlist, struct rfc822_token **tlistp));
+extern const char *_unfold __((const char *start, const char *end, struct rfc822_token *t));
+extern struct rfc822_token * scan822 __((const char **cpp, size_t n, int c1, int c2,
+				  int allowcomments, struct rfc822_token **tlistp));
 #endif
 
 /* selfaddrs.c */
@@ -152,18 +152,18 @@
 
 /* token.c */
 #ifdef Z_TOKEN_H
-extern struct token *makeToken __((const char *s, u_int n));
-extern struct token *copyToken __((struct token *t));
-extern const char *formatToken __((struct token *t));
+extern struct rfc822_token *makeToken __((const char *s, u_int n));
+extern struct rfc822_token *copyToken __((struct rfc822_token *t));
+extern const char *formatToken __((struct rfc822_token *t));
 extern int  printToken  __((char *buf, char *eob,
-			    struct token *t, struct token *tend,
+			    struct rfc822_token *t, struct rfc822_token *tend,
 			    int quotespecials));
 extern int  printdToken __((char **bufp, int *buflenp,
-			    struct token *t, struct token *tend,
+			    struct rfc822_token *t, struct rfc822_token *tend,
 			    int quotespecials));
-extern int  fprintToken __((FILE *fp, struct token *t, int onlylength));
-extern int  fprintFold  __((FILE *fp, struct token *t, int col));
-extern void freeTokens __((struct token *t, int memtype));
+extern int  fprintToken __((FILE *fp, struct rfc822_token *t, int onlylength));
+extern int  fprintFold  __((FILE *fp, struct rfc822_token *t, int col));
+extern void freeTokens __((struct rfc822_token *t, int memtype));
 #ifdef TOKENLEN /* Defined in  "mailer.h", like AddrComponent too.. */
 extern const char *formatAddr __((AddrComponent d));
 #endif
Only in zmailer-2.99.49p9-p0/include: libz.h.Orig
diff -u -r zmailer-2.99.49p9/include/mailer.h zmailer-2.99.49p9-p0/include/mailer.h
--- zmailer-2.99.49p9/include/mailer.h	Sat Jun 14 10:30:26 1997
+++ zmailer-2.99.49p9-p0/include/mailer.h	Tue Nov 11 10:21:34 1997
@@ -109,7 +109,7 @@
 
 struct addr {
 	AddrComponent	p_type;
-	struct token	*p_tokens;
+	struct rfc822_token	*p_tokens;
 	struct addr	*p_next;
 };
 
@@ -135,17 +135,17 @@
 struct received {
 	struct address	*r_from;	
 	struct address	*r_by;
-	struct token	*r_via;
-	struct token	*r_with;
+	struct rfc822_token	*r_via;
+	struct rfc822_token	*r_with;
 	struct address	*r_id;
 	struct address	*r_for;
-	struct token	*r_convert;
+	struct rfc822_token	*r_convert;
 	time_t		r_time;
 };
 
 union misc {					/* what a header can be */
 	struct address	*a;
-	struct token	*t;
+	struct rfc822_token	*t;
 	struct received	*r;
 	time_t		d; 
 };
@@ -197,7 +197,7 @@
 	const char	*h_pname;	/* printable representation */
 	union misc	h_contents;	/* contents depending on type */
 	struct headerinfo *h_descriptor; /* characteristics of header */
-	struct token	*h_lines;	/* original header lines */
+	struct rfc822_token	*h_lines;	/* original header lines */
 	HeaderStamp	h_stamp;	/* what this is */
 	struct header	*h_next;
 };
@@ -234,9 +234,9 @@
 };
 
 #ifdef	RFC976
-#define HDR_SCANNER(x)	scan822(&(x), strlen((const char *)x), '!', '%', 0, (struct token **)0)
+#define HDR_SCANNER(x)	scan822(&(x), strlen((const char *)x), '!', '%', 0, (struct rfc822_token **)0)
 #else	/* !RFC976 */
-#define HDR_SCANNER(x)	scan822(&(x), strlen((const char *)x), 0, 0, 0, (struct token **)0)
+#define HDR_SCANNER(x)	scan822(&(x), strlen((const char *)x), 0, 0, 0, (struct rfc822_token **)0)
 #endif	/* RFC976 */
 
 /* #include "libz.h" */
Only in zmailer-2.99.49p9-p0/include: mailer.h.Orig
diff -u -r zmailer-2.99.49p9/include/token.h zmailer-2.99.49p9-p0/include/token.h
--- zmailer-2.99.49p9/include/token.h	Sun May 11 17:21:53 1997
+++ zmailer-2.99.49p9-p0/include/token.h	Tue Nov 11 10:21:34 1997
@@ -11,11 +11,11 @@
 	Line, String, Space, Special, Word, Empty
 } TokenType;
 
-struct token {
+struct rfc822_token {
 	const char	*t_pname;		/* printable representation */
 	u_long		 t_len;			/* length (0 if malloc'ed) */
 	TokenType	 t_type;		/* information on token type */
-	struct token	*t_next;
+	struct rfc822_token	*t_next;
 };
 
 #endif	/* Z_TOKEN_H */
Only in zmailer-2.99.49p9-p0/include: token.h.Orig
diff -u -r zmailer-2.99.49p9/lib/rfc822scan.c zmailer-2.99.49p9-p0/lib/rfc822scan.c
--- zmailer-2.99.49p9/lib/rfc822scan.c	Wed May 14 16:21:55 1997
+++ zmailer-2.99.49p9-p0/lib/rfc822scan.c	Tue Nov 11 10:21:34 1997
@@ -138,9 +138,9 @@
 	long	n;
 	int	cstart, cend;
 	TokenType	type;
-	struct token	*tp, **tlist, **tlistp;
+	struct rfc822_token	*tp, **tlist, **tlistp;
 {
-	struct token *tn;
+	struct rfc822_token *tn;
 
 	if (*cp != cstart)
 		abort(); /* Sanity check!  Call fault! */
@@ -195,7 +195,7 @@
 const char *
 _unfold(start, end, t)
 	const char *start, *end;
-	struct token *t;
+	struct rfc822_token *t;
 {
 	char *s, *cp;
 	/*
@@ -237,16 +237,16 @@
  * for efficiency this was changed to avoid function call overhead. The tokens
  * returned are classified by type (TokenType enum class).
  */
-struct token * scan822(cpp, nn, c1, c2, allowcomments, tlistp)
+struct rfc822_token * scan822(cpp, nn, c1, c2, allowcomments, tlistp)
 	const char **cpp;		/* pointer to pointer to text */
 	size_t	nn;			/* number of characters to scan */
 	int	c1, c2;			/* temporary specials */
 	int allowcomments;		/* #prefix tokens are comments to EOT */
-	struct token **tlistp;		/* continuation line tokens if any */
+	struct rfc822_token **tlistp;		/* continuation line tokens if any */
 {
 	register const char *cp;
-	static struct token  t;
-	struct token	*tlist, *tp, *tn, *ot;
+	static struct rfc822_token  t;
+	struct rfc822_token	*tlist, *tp, *tn, *ot;
 	char	msgbuf[50];
 	short	ct, sc1, sc2;
 	int n = (int) nn;
Only in zmailer-2.99.49p9-p0/lib: rfc822scan.c.Orig
diff -u -r zmailer-2.99.49p9/lib/token.c zmailer-2.99.49p9-p0/lib/token.c
--- zmailer-2.99.49p9/lib/token.c	Wed May 14 17:12:14 1997
+++ zmailer-2.99.49p9-p0/lib/token.c	Tue Nov 11 10:21:34 1997
@@ -13,14 +13,14 @@
 #include <ctype.h>
 #include "libz.h"
 
-struct token *
+struct rfc822_token *
 makeToken(s, n)
 	const char	*s;
 	register u_int	n;
 {
-	register struct token	*t;
+	register struct rfc822_token	*t;
 
-	t = (struct token *)tmalloc(sizeof (struct token));
+	t = (struct rfc822_token *)tmalloc(sizeof (struct rfc822_token));
 	t->t_pname = strnsave(s, n);
 	t->t_len = 0;
 	t->t_type = Empty;
@@ -28,11 +28,11 @@
 	return t;
 }
 
-struct token *
+struct rfc822_token *
 copyToken(t)
-	register struct token *t;
+	register struct rfc822_token *t;
 {
-	register struct token *ct;
+	register struct rfc822_token *ct;
 	int tlen;
 	
 	if (stickymem != MEM_TEMP) {
@@ -48,7 +48,7 @@
 		tlen = 50000; /* We use AT MOST 50k from start! */
 	}
 
-	ct = (struct token *)tmalloc(sizeof (struct token));
+	ct = (struct rfc822_token *)tmalloc(sizeof (struct rfc822_token));
 	if (stickymem != MEM_TEMP)
 	  ct->t_pname = strnsave((const char *)t->t_pname, tlen);
 	else
@@ -62,7 +62,7 @@
 
 const char *
 formatToken(t)
-	register struct token *t;
+	register struct rfc822_token *t;
 {
 	const char *name;
 	int len;
@@ -112,7 +112,7 @@
 int
 printToken(buf, eob, t, tend, quotespecials)
 	char *buf, *eob;
-	register struct token *t, *tend;
+	register struct rfc822_token *t, *tend;
 	int quotespecials;
 {
 	register char *cp;
@@ -141,7 +141,7 @@
 int
 printdToken(bufp, buflenp, t, tend, quotespecials)
 	char **bufp;
-	register struct token *t, *tend;
+	register struct rfc822_token *t, *tend;
 	int quotespecials, *buflenp;
 {
 	register char *cp, *buf = *bufp;
@@ -179,7 +179,7 @@
 int
 fprintToken(fp, t, onlylength)
 	FILE *fp;
-	struct token *t;
+	struct rfc822_token *t;
 	int onlylength;
 {
 	int len;
@@ -217,7 +217,7 @@
 int
 fprintFold(fp, t, col)
 	FILE *fp;
-	struct token *t;
+	struct rfc822_token *t;
 	int col;
 {
 	int len;
@@ -291,10 +291,10 @@
 
 void
 freeTokens(t, memtype)
-	struct token *t;
+	struct rfc822_token *t;
 	int memtype;
 {
-	struct token *nt;
+	struct rfc822_token *nt;
 
 	if (memtype != MEM_MALLOC)
 		return;
Only in zmailer-2.99.49p9-p0/lib: token.c.Orig
diff -u -r zmailer-2.99.49p9/libsh/interpret.c zmailer-2.99.49p9-p0/libsh/interpret.c
--- zmailer-2.99.49p9/libsh/interpret.c	Fri Oct 31 01:22:09 1997
+++ zmailer-2.99.49p9-p0/libsh/interpret.c	Tue Nov 11 10:21:34 1997
@@ -1150,15 +1150,15 @@
 	short	varindex;	/* index of active loop variable */
 };
 
-STATIC struct token *tscanstring __((const char *));
+STATIC struct rfc822_token *tscanstring __((const char *));
 STATIC
-struct token *
+struct rfc822_token *
 tscanstring(s)
 	const char *s;
 {
 	const char *cp;
 	int len;
-	struct token *t;
+	struct rfc822_token *t;
 
 	t = HDR_SCANNER(s);
 	if (t != NULL && t->t_next == NULL && t->t_type == String) {
Only in zmailer-2.99.49p9-p0/libsh: interpret.c.Orig
diff -u -r zmailer-2.99.49p9/libsh/sift.h zmailer-2.99.49p9-p0/libsh/sift.h
--- zmailer-2.99.49p9/libsh/sift.h	Mon May 12 12:45:02 1997
+++ zmailer-2.99.49p9-p0/libsh/sift.h	Tue Nov 11 10:21:34 1997
@@ -27,13 +27,13 @@
 	regexp		*rep;
 	tregexp		*trep;
 	const char	**match;
-	struct token	*startp[NSUBEXP];
-	struct token	*endp[NSUBEXP];
+	struct rfc822_token	*startp[NSUBEXP];
+	struct rfc822_token	*endp[NSUBEXP];
 };
 
 struct siftinfo {
 	int		kind;		/* 0: StringSift, !0: TokenSift */
-	struct token	*tlist;		/* token list for tsift expression */
+	struct rfc822_token	*tlist;		/* token list for tsift expression */
 	const char	*str;		/* string for sift expression */
 	struct vaccess	*accessed;	/* variables dependencies of expr. */
 	int		label;		/* label to go to when reevaluating */
Only in zmailer-2.99.49p9-p0/libsh: sift.h.Orig
diff -u -r zmailer-2.99.49p9/libsh/tregexp.h zmailer-2.99.49p9-p0/libsh/tregexp.h
--- zmailer-2.99.49p9/libsh/tregexp.h	Mon May 12 14:55:10 1997
+++ zmailer-2.99.49p9-p0/libsh/tregexp.h	Tue Nov 11 10:21:34 1997
@@ -11,11 +11,11 @@
 #define NSUBEXP  10
 typedef struct tregexp {
 #if 0
-	struct token *startp[NSUBEXP];
-	struct token *endp[NSUBEXP];
+	struct rfc822_token *startp[NSUBEXP];
+	struct rfc822_token *endp[NSUBEXP];
 #else
-	struct token **startp;
-	struct token **endp;
+	struct rfc822_token **startp;
+	struct rfc822_token **endp;
 #endif
 	char regstart;		/* Internal use only. */
 	char reganch;		/* Internal use only. */
@@ -26,7 +26,7 @@
 } tregexp;
 
    tregexp *tregcomp  __((const char *));
-       int  tregexec  __((tregexp *, struct token *));
+       int  tregexec  __((tregexp *, struct rfc822_token *));
 const char *tregsub   __((tregexp *, int));
       void  tregerror __((const char *, tregexp *));
       void  tregdump  __((tregexp *));
Only in zmailer-2.99.49p9-p0/libsh: tregexp.h.Orig
diff -u -r zmailer-2.99.49p9/router/dateparse.c zmailer-2.99.49p9-p0/router/dateparse.c
--- zmailer-2.99.49p9/router/dateparse.c	Fri Jul 22 05:40:45 1994
+++ zmailer-2.99.49p9-p0/router/dateparse.c	Tue Nov 11 10:21:35 1997
@@ -279,7 +279,7 @@
 long
 dateParse(localtmptr, t)
 	struct tm *localtmptr;
-	struct token *t;
+	struct rfc822_token *t;
 {
 	register int	val = 0, i, could_be;
 	int	century, year, month, dayinmonth, julian;
Only in zmailer-2.99.49p9-p0/router: dateparse.c.Orig
diff -u -r zmailer-2.99.49p9/router/functions.c zmailer-2.99.49p9-p0/router/functions.c
--- zmailer-2.99.49p9/router/functions.c	Wed Oct 15 19:23:04 1997
+++ zmailer-2.99.49p9-p0/router/functions.c	Tue Nov 11 10:21:35 1997
@@ -1278,7 +1278,7 @@
 	struct header hs;
 	struct envelope *e;
 	struct address *ap, *aroot = NULL, **atail = &aroot;
-	struct token *t;
+	struct rfc822_token *t;
 	conscell *al, *alp = NULL, *tmp;
 	char *localpart, *origaddr, *attributenam;
 	int c, n, errflag, stuff;
@@ -1733,7 +1733,7 @@
 	struct header hs;
 	struct envelope *e;
 	struct address *ap, *aroot = NULL, **atail = &aroot;
-	struct token *t;
+	struct rfc822_token *t;
 	struct addr *pp;
 	int c, n, errflag, stuff;
 	const char *comment, *erroraddress;
Only in zmailer-2.99.49p9-p0/router: functions.c.Orig
diff -u -r zmailer-2.99.49p9/router/prototypes.h zmailer-2.99.49p9-p0/router/prototypes.h
--- zmailer-2.99.49p9/router/prototypes.h	Fri Oct 24 23:00:49 1997
+++ zmailer-2.99.49p9-p0/router/prototypes.h	Tue Nov 11 10:21:35 1997
@@ -66,7 +66,7 @@
 extern struct sptree_init splaytrees[];
 
 /* File: dateparse.c */
-extern long	dateParse __((struct tm *localtmptr, struct token *t));
+extern long	dateParse __((struct tm *localtmptr, struct rfc822_token *t));
 
 /* File: db.c */
 extern int	run_relation __((int argc, const char *argv[]));
@@ -148,7 +148,7 @@
 
 /* File: rfc822walk.c */
 extern struct address	*revaddress __((struct address *ap));
-extern union misc	 parse822 __((HeaderSemantics entry, struct token **tlistp, struct tm *ltm, FILE *tfp));
+extern union misc	 parse822 __((HeaderSemantics entry, struct rfc822_token **tlistp, struct tm *ltm, FILE *tfp));
 
 
 /* File: router.c */
Only in zmailer-2.99.49p9-p0/router: prototypes.h.Orig
diff -u -r zmailer-2.99.49p9/router/rfc822.c zmailer-2.99.49p9-p0/router/rfc822.c
--- zmailer-2.99.49p9/router/rfc822.c	Mon Oct 27 05:39:20 1997
+++ zmailer-2.99.49p9-p0/router/rfc822.c	Tue Nov 11 10:21:35 1997
@@ -279,7 +279,7 @@
 				h->h_lines->t_type = Line;
 			} else if (inheader && n > 1) {
 				/* append to the header we just saw */
-				struct token *t;
+				struct rfc822_token *t;
 				if (e->e_headers == NULL) {
 				  /* Wow, continuation without previous header! */
 				  /* It must be body.. */
@@ -401,7 +401,7 @@
 dumpHeader(h)
 	struct header *h;
 {
-	struct token	*t;
+	struct rfc822_token	*t;
 	struct address	*a;
 	struct addr	*p;
 
@@ -1115,7 +1115,7 @@
 	char	       *ofpname, *path, *qpath;
 	conscell       *l, *routed_addresses, *sender, *to;
 	struct rwmatrix *rwhead, *nsp, *rwp = NULL, *rcp = NULL;
-	struct token   *t = NULL;
+	struct rfc822_token   *t = NULL;
 	int   idnumber, nxor, i;
 	int   def_uid, header_error, perr;
 	FILE	       *ofp, *vfp;
@@ -1866,7 +1866,7 @@
 			h->h_contents.a->a_tokens->p_tokens->t_type = Atom;
 		printToken(verbosefile, verbosefile + sizeof verbosefile,
 			   h->h_contents.a->a_tokens->p_tokens,
-			   (struct token *)NULL, 0);
+			   (struct rfc822_token *)NULL, 0);
 		/*
 		 * We have to be careful how we open this file, since one might
 		 * imagine someone trying to append to /etc/passwd using this
Only in zmailer-2.99.49p9-p0/router: rfc822.c.Orig
diff -u -r zmailer-2.99.49p9/router/rfc822hdrs.c zmailer-2.99.49p9-p0/router/rfc822hdrs.c
--- zmailer-2.99.49p9/router/rfc822hdrs.c	Mon May 26 12:51:49 1997
+++ zmailer-2.99.49p9-p0/router/rfc822hdrs.c	Tue Nov 11 10:21:35 1997
@@ -38,12 +38,12 @@
 	struct header *h;
 	int commentflag, no_line_crossing;
 {
-	register struct token *t;
+	register struct rfc822_token *t;
 	long		 len;
 	const char	*cp, *ocp;
 	char		 c1, c2;
 	union misc	 retval;
-	struct token	*tlist, **prev_tp, *scan_t, *nt;
+	struct rfc822_token	*tlist, **prev_tp, *scan_t, *nt;
 	struct headerinfo *hd;
 
 	/* If we don't recognize the header, we can't parse it */
@@ -411,7 +411,7 @@
 	FILE *fp;
 {
 	int col, addrlen, newline;
-	struct token *t;
+	struct rfc822_token *t;
 	struct address *ap;
 	struct addr *pp;
 
@@ -613,7 +613,7 @@
 	FILE *fp;
 	register struct addr *pp;
 {
-	register struct token *t;
+	register struct rfc822_token *t;
 
 	for (; pp != NULL ; pp = pp->p_next) {
 		if (pp->p_type != anAddress)
@@ -654,7 +654,7 @@
 	int onlylength;
 {
 	int inAddress;
-	struct token *t;
+	struct rfc822_token *t;
 	struct addr *lastp, *tpp;
 
 	inAddress = 0;
@@ -728,7 +728,7 @@
 	int col;
 {
 	int inAddress;
-	struct token *t;
+	struct rfc822_token *t;
 	struct addr *lastp, *tpp;
 
 	inAddress = 0;
@@ -813,7 +813,7 @@
 {
 	int len, totallen, inAddress;
 	char *cp, *buf;
-	struct token *t;
+	struct rfc822_token *t;
 	struct addr *lastp, *tpp;
 
 	totallen = printAddress((FILE *)NULL, pp, 1);
@@ -895,9 +895,9 @@
 	int hdrlen;
 {
 	int inAddress, n, i, j, len;
-	struct token *t;
+	struct rfc822_token *t;
 	struct addr *lastp, *tpp;
-	struct { int pos; struct token *tokens; } errmsg[200];
+	struct { int pos; struct rfc822_token *tokens; } errmsg[200];
 
 	inAddress = 0;
 	for (lastp = NULL, tpp = pp; tpp != NULL; tpp = tpp->p_next)
Only in zmailer-2.99.49p9-p0/router: rfc822hdrs.c.Orig
diff -u -r zmailer-2.99.49p9/router/rfc822test.c zmailer-2.99.49p9-p0/router/rfc822test.c
--- zmailer-2.99.49p9/router/rfc822test.c	Wed Jan 31 17:56:52 1996
+++ zmailer-2.99.49p9-p0/router/rfc822test.c	Tue Nov 11 10:21:35 1997
@@ -13,7 +13,7 @@
 int D_alloc = 0;
 
 extern union misc parse822();
-extern struct token *readlines();
+extern struct rfc822_token *readlines();
 extern time_t time();
 extern int fprintToken();
 
@@ -22,13 +22,13 @@
 	int argc;
 	char *argv[];
 {
-	register struct token *t;
+	register struct rfc822_token *t;
 	u_long	len;
 	time_t now;
 	u_char	*cp, *ocp;
 	int c;
 	HeaderSemantics entry_pt;
-	struct token *tlist, **prev_tp, *scan_t, *nt;
+	struct rfc822_token *tlist, **prev_tp, *scan_t, *nt;
 	struct address *a;
 	struct addr *p;
 	struct tm localtm;
@@ -150,10 +150,10 @@
 	exit(0);
 }
 
-struct token *
+struct rfc822_token *
 readlines()
 {
-	struct token *t, **pt;
+	struct rfc822_token *t, **pt;
 	char buf[BUFSIZ];
 
 	pt = &t;
@@ -193,9 +193,9 @@
 	register struct addr *pp;
 {
 	int inAddress, n, i, j, len;
-	struct token *t;
+	struct rfc822_token *t;
 	struct addr *lastp, *tpp;
-	struct { int pos; struct token *tokens; } errmsg[200];
+	struct { int pos; struct rfc822_token *tokens; } errmsg[200];
 
 	inAddress = 0;
 	for (lastp = NULL, tpp = pp; tpp != NULL; tpp = tpp->p_next)
Only in zmailer-2.99.49p9-p0/router: rfc822test.c.Orig
diff -u -r zmailer-2.99.49p9/router/rfc822walk.c zmailer-2.99.49p9-p0/router/rfc822walk.c
--- zmailer-2.99.49p9/router/rfc822walk.c	Sun May 11 17:41:06 1997
+++ zmailer-2.99.49p9-p0/router/rfc822walk.c	Tue Nov 11 10:21:36 1997
@@ -15,14 +15,14 @@
 STATIC		/* This will apply to the array in the .sst file */
 #include "rfc822.sst.c"
 
-extern void	EmitToken __((struct token *t, ComponentClass ac, struct address *ap));
+extern void	EmitToken __((struct rfc822_token *t, ComponentClass ac, struct address *ap));
 STATIC const char * Input822TokenName __((int));
 
 /* private semantics mechanism variables: */
 STATIC ComponentClass currentTokenType;
-STATIC struct token *ptrNextInputToken, *ptrAcceptedToken;
-STATIC struct token *headPending, **pending;
-STATIC struct token *headDeferred, **deferred;
+STATIC struct rfc822_token *ptrNextInputToken, *ptrAcceptedToken;
+STATIC struct rfc822_token *headPending, **pending;
+STATIC struct rfc822_token *headDeferred, **deferred;
 
 /* Table Walker State */
 STATIC int	processing;		/* are we running the table walker? */
@@ -33,7 +33,7 @@
 /* convenience */
 STATIC struct address nullAddr = { NULL, NULL, newAddress, 0, NULL, NULL };
 #ifdef ATHACK
-STATIC struct token atsigntoken = { "@", 1, Special, NULL };
+STATIC struct rfc822_token atsigntoken = { "@", 1, Special, NULL };
 #endif
 
 /* Tracing Control */
@@ -151,7 +151,7 @@
 	ErrorCodes errCode;
 	struct address *ap;
 {
-	struct token *t;
+	struct rfc822_token *t;
 	int i;
 
 	if (errCode == eNoError)
@@ -183,10 +183,10 @@
  * indicators and the values and text associated with input tokens.  
  */
 
-STATIC void AcceptInputToken __((struct token **, struct address *));
+STATIC void AcceptInputToken __((struct rfc822_token **, struct address *));
 STATIC void
 AcceptInputToken(tlistp, ap)
-	struct token **tlistp;
+	struct rfc822_token **tlistp;
 	struct address *ap;
 {
 
@@ -345,10 +345,10 @@
  * been matched.
  */
 
-STATIC void SslSyntaxError __((struct token **, struct address *));
+STATIC void SslSyntaxError __((struct rfc822_token **, struct address *));
 STATIC void
 SslSyntaxError(tlistp, ap)
-	struct token **tlistp;
+	struct rfc822_token **tlistp;
 	struct address *ap;
 {
 	if (operation != oInput && operation != oInputAny)
@@ -538,11 +538,11 @@
 
 void
 EmitToken(t, ac, ap)
-	struct token *t;
+	struct rfc822_token *t;
 	ComponentClass ac;
 	struct address *ap;
 {
-	struct token *nt, **ptp;
+	struct rfc822_token *nt, **ptp;
 	struct addr *na;
 	AddrComponent type;
 
@@ -618,7 +618,7 @@
 revaddress(ap)
 	struct address *ap;
 {
-	register struct token	*rprev, *rnext, *r;
+	register struct rfc822_token	*rprev, *rnext, *r;
 	register struct addr	*pprev, *pnext, *p;
 
 	/* reverse order of address components and tokens */
@@ -642,14 +642,14 @@
 	return ap;
 }
 
-STATIC void revappend __((struct token **, struct address *));
+STATIC void revappend __((struct rfc822_token **, struct address *));
 STATIC void
 revappend(tprev,ap)
-struct token **tprev;
+struct rfc822_token **tprev;
 struct address *ap;
 {
 	struct addr *p;
-	struct token *t;
+	struct rfc822_token *t;
 
 	ap = revaddress(ap);
 	/* append all the tokens together */
@@ -685,12 +685,12 @@
 union misc
 parse822(entry, tlistp, ltmp, tfp)
 	HeaderSemantics	entry;
-	struct token **tlistp;
+	struct rfc822_token **tlistp;
 	struct tm *ltmp;
 	FILE *tfp;
 {
 	int		inReceived, i;
-	struct token	*t, *torig;
+	struct rfc822_token	*t, *torig;
 	struct address	*ap, *na, *pap;
 	struct received	rcvd;
 	union misc	retval;
Only in zmailer-2.99.49p9-p0/router: rfc822walk.c.Orig
diff -u -r zmailer-2.99.49p9/router/shliaise.c zmailer-2.99.49p9-p0/router/shliaise.c
--- zmailer-2.99.49p9/router/shliaise.c	Fri Oct 31 12:05:36 1997
+++ zmailer-2.99.49p9-p0/router/shliaise.c	Tue Nov 11 10:21:36 1997
@@ -66,13 +66,13 @@
  * This is used to rewrite an address.
  */
 
-static int s_rewrite __((const char *func, struct token *t,
+static int s_rewrite __((const char *func, struct rfc822_token *t,
 			 const char *sender, const char *argx));
 
 static int
 s_rewrite(func, t, sender, argx)
 	const char *func, *sender, *argx;
-	struct token *t;
+	struct rfc822_token *t;
 {
 	register char *cp, *bp;
 	const char *av[4];
@@ -83,7 +83,7 @@
 	if (t == NULL)
 		return 0;
 	cp = buf;
-	cp += printdToken(&buf, &bufspc, t, (struct token *)NULL, 0);
+	cp += printdToken(&buf, &bufspc, t, (struct rfc822_token *)NULL, 0);
 	/* Was it a quote-containing string ?  If so, strip the quotes,
 	   and undo back-slash quoting */
 	if (t->t_next == NULL && t->t_type == String && buf[0] == '"') {
@@ -121,15 +121,15 @@
  * ignored.
  */
 
-static struct addr *mergeAddress __((struct addr *pp, struct token *t));
+static struct addr *mergeAddress __((struct addr *pp, struct rfc822_token *t));
 
 static struct addr *
 mergeAddress(pp, t)
 	struct addr *pp;
-	struct token *t;
+	struct rfc822_token *t;
 {
 	struct addr *ppp, *npp, *fpp;
-	struct token *nt, *pt;
+	struct rfc822_token *nt, *pt;
 
 	pt = NULL;
 	for (ppp = fpp = NULL; pp != NULL; pp = pp->p_next, ppp = npp) {
@@ -170,9 +170,9 @@
 {
 	register struct address *ap;
 	register struct addr *pp;
-	register struct token *t;
+	register struct rfc822_token *t;
 	struct address *nap = NULL, *pap;
-	struct token *nt, *pt, *addrtokens;
+	struct rfc822_token *nt, *pt, *addrtokens;
 	struct header *nh;
 	conscell *l;
 	const char *cp, *eocp;
@@ -454,9 +454,9 @@
 	int uid;
 	const char *type;
 {
-	register struct token *t, *tt;
+	register struct rfc822_token *t, *tt;
 	int r;
-	struct token *last;
+	struct rfc822_token *last;
 	struct addr *p;
 	conscell *l, *tmp;
 	const char *gsym;
Only in zmailer-2.99.49p9-p0/router: shliaise.c.Orig
diff -u -r zmailer-2.99.49p9/libsh/tregexp.c zmailer-2.99.49p9-p0/libsh/tregexp.c
--- zmailer-2.99.49p9/libsh/tregexp.c	Thu May 22 18:17:14 1997
+++ zmailer-2.99.49p9-p0/libsh/tregexp.c	Tue Nov 11 10:21:34 1997
@@ -40,7 +40,7 @@
 /*
  * This code has been altered to deal with token sequences instead of
  * character strings. The modifications can mostly be identified by the
  * appearance of struct token * variables. In addition, the character
  * class stuff has been removed (perhaps it should be revised instead).
  * Any errors in these changes are of course not to be attributed to the
  * original author of this regular expression code, whom I thank for
@@ -188,8 +188,8 @@
 STATIC const char *regpiece  __((int *));
 STATIC       int   regmatch  __((const char *));
 STATIC       int   regrepeat __((const char *));
-STATIC       int   regtoken  __((struct token **, const char *, int));
-STATIC       int   regtry    __((tregexp *, struct token *));
+STATIC       int   regtoken  __((struct rfc822_token **, const char *, int));
+STATIC       int   regtry    __((tregexp *, struct rfc822_token *));
 STATIC       void  regc      __((int));
 STATIC       void  reginsert __((int, const char *));
 STATIC       void  regoptail __((const char *, const char *));
@@ -737,11 +737,11 @@
 /*
  * Global work variables for tregexec().
  */
-STATIC struct token *reginput;		/* String-input pointer. */
-STATIC struct token *previnput;		/* Previous string-input pointer. */
-STATIC struct token *regbol;		/* Beginning of input, for ^ check. */
-STATIC struct token **regstartp;	/* Pointer to startp array. */
-STATIC struct token **regendp;		/* Ditto for endp. */
+STATIC struct rfc822_token *reginput;		/* String-input pointer. */
+STATIC struct rfc822_token *previnput;		/* Previous string-input pointer. */
+STATIC struct rfc822_token *regbol;		/* Beginning of input, for ^ check. */
+STATIC struct rfc822_token **regstartp;	/* Pointer to startp array. */
+STATIC struct rfc822_token **regendp;		/* Ditto for endp. */
 STATIC short regatomize[10] = { 0 };	/* if on turn DomainLiteral->Atom */
 
 /*
@@ -750,9 +750,9 @@
 int
 tregexec(prog, tstring)
 	register tregexp *prog;
-	register struct token *tstring;
+	register struct rfc822_token *tstring;
 {
-	register struct token *s;
+	register struct rfc822_token *s;
 
 	regprog = prog;
 	/* Be paranoid... */
@@ -784,7 +784,7 @@
 	/* If there is a "must appear" string, look for it. */
 	if (prog->regmust != NULL) {
 		int rmlen, len;
-		struct token *t;
+		struct rfc822_token *t;
 
 		for (s = tstring; s != NULL; s = s->t_next) {
 			const char *cp;
@@ -846,7 +846,7 @@
 
 STATIC int
 regtoken(tp, s, maxlen)
-	struct token **tp;		/* the token to match with */
+	struct rfc822_token **tp;		/* the token to match with */
 	const char *s;			/* the string to match with */
 	int maxlen;			/* how long the string is */
 {
@@ -883,11 +883,11 @@
 STATIC int			/* 0 failure, 1 success */
 regtry(prog, tstring)
 	tregexp *prog;
-	struct token *tstring;
+	struct rfc822_token *tstring;
 {
 	register int i;
-	struct token **sp;
-	struct token **ep;
+	struct rfc822_token **sp;
+	struct rfc822_token **ep;
 
 	previnput = NULL;
 	reginput = tstring;
@@ -960,7 +960,7 @@
 			previnput = reginput, reginput = reginput->t_next;
 			break;
 		case EXACTLY: {
-				struct token *t;
+				struct rfc822_token *t;
 				register int len, toklen;
 				register const char *opnd;
 
@@ -1025,7 +1025,7 @@
 		case OPEN+8:
 		case OPEN+9: {
 				register int no;
-				register struct token *save;
+				register struct rfc822_token *save;
 
 				no = OP(scan) - OPEN;
 				save = reginput;
@@ -1059,7 +1059,7 @@
 		case CLOSE+8:
 		case CLOSE+9: {
 				register int no;
-				register struct token *save;
+				register struct rfc822_token *save;
 
 				no = OP(scan) - CLOSE;
 				save = reginput;
@@ -1077,7 +1077,7 @@
 			}
 			return(0);
 		case BRANCH: {
-				register struct token *save, *saveprev;
+				register struct rfc822_token *save, *saveprev;
 
 				if (OP(next) != BRANCH)		/* No choice. */
 					next = OPERAND(scan);	/* Avoid recursion. */
@@ -1100,7 +1100,7 @@
 		case PLUS: {
 				register const char *nextch;
 				register int no, i;
-				register struct token *save, *saveprev;
+				register struct rfc822_token *save, *saveprev;
 				register int min;
 
 				/*
@@ -1156,7 +1156,7 @@
 	const char *p;
 {
 	register int    count = 0;
-	register struct token *scan;
+	register struct rfc822_token *scan;
 	register const  char  *opnd;
 
 	scan = reginput;
@@ -1379,7 +1379,7 @@
 	tregexp *prog;
 	int n;
 {
-	register struct token *ts, *te;
+	register struct rfc822_token *ts, *te;
 	char *cp;
 	int len;
 	int buflen;
@@ -40,7 +40,7 @@
  * This code has been altered to deal with token sequences instead of
  * character strings. The modifications can mostly be identified by the
- * appearance of struct token * variables. In addition, the character
+ * appearance of struct rfc822_token * variables. In addition, the character
  * class stuff has been removed (perhaps it should be revised instead).
  * Any errors in these changes are of course not to be attributed to the
Only in zmailer-2.99.49p9-p0/libsh: tregexp.c.Orig